@@ -429,8 +429,16 @@ SelectAbacus(AbacusWidget w, XEvent * event, char **args, int nArgs)
 {
 	int         deck, rail, j;
 
-	if (!w->abacus.demo &&
-	    PositionToBead(w, event->xbutton.x, event->xbutton.y, &deck, &rail, &j)) {
+	if (w->abacus.demo) {
+		ClearAllBeads(w);
+		if (w->abacus.demo) {
+			abacusCallbackStruct cb;
+
+			cb.reason = ABACUS_CLEAR;
+			XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
+		}
+		w->abacus.currentDeck = -1;
+	} else if (PositionToBead(w, event->xbutton.x, event->xbutton.y, &deck, &rail, &j)) {
 		w->abacus.currentDeck = deck;
 		w->abacus.currentRail = rail;
 		w->abacus.currentPosition = j;
@@ -454,15 +462,17 @@ ReleaseAbacus(AbacusWidget w, XEvent * event, char **args, int nArgs)
 static void
 ClearAbacus(AbacusWidget w, XEvent * event, char **args, int nArgs)
 {
-	if (!EmptyCounter(w)) {
+#if 0
+	if (EmptyCounter(w))
+		return;
 		/* Should check if one really wants to destroy calculations. */
-		ClearAllBeads(w);
-		if (w->abacus.demo) {
-			abacusCallbackStruct cb;
+#endif
+	ClearAllBeads(w);
+	if (w->abacus.demo) {
+		abacusCallbackStruct cb;
 
-			cb.reason = ABACUS_CLEAR;
-			XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
-		}
+		cb.reason = ABACUS_CLEAR;
+		XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
 	}
 }
 
